==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-reactive-streams/src/main/java/org/apache/camel/component/reactive/streams/ReactiveStreamsConverter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.reactive.streams;

import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.Converter;
import org.apache.camel.Exchange;
import org.apache.camel.FallbackConverter;
import org.apache.camel.component.reactive.streams.util.MonoPublisher;
import org.apache.camel.spi.TypeConverterRegistry;
import org.reactivestreams.Publisher;


@Converter
public final class ReactiveStreamsConverter implements CamelContextAware {

    private CamelContext camelContext;

    public ReactiveStreamsConverter() {
    }

    @FallbackConverter
    public Object convertToPublisher(Class<?> type, Exchange exchange, Object value, TypeConverterRegistry registry) {
        if (type.isAssignableFrom(Publisher.class)) {
            return new MonoPublisher<>(value);
        }
        return null;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-reactive-streams/src/main/java/org/apache/camel/component/reactive/streams/ReactiveStreamsConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.reactive.streams;

import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.Converter;
import org.apache.camel.Exchange;
import org.apache.camel.component.reactive.streams.util.MonoPublisher;
import org.apache.camel.spi.TypeConverterRegistry;
import org.reactivestreams.Publisher;

@Converter(generateLoader = true)
public final class ReactiveStreamsConverter implements CamelContextAware {

    private CamelContext camelContext;

    public ReactiveStreamsConverter() {
    }

    @Converter(fallback = true)
    public Object convertToPublisher(Class<?> type, Exchange exchange, Object value, TypeConverterRegistry registry) {
        if (type.isAssignableFrom(Publisher.class)) {
            return new MonoPublisher<>(value);
        }
        return null;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }
}
